﻿// Standard .NET dependencies
using System;
using System.Collections.Generic;
using System.IO;
using System.Threading;

// Google dependencies
using Google.Apis.Calendar.v3;
using Google.Apis.Calendar.v3.Data;
using Google.Apis.Services;
using Google.Apis.Auth.OAuth2;
using Google.Apis.Util.Store;

// Project dependencies
using CommonTools;

namespace GoogleTools
{
    public class GoogleExtractor : IExtractor
    {
        List<string> scopes = new List<string>();
        CalendarService service;

        /// <summary>
        /// Loads updated event from Google Calender after a date
        /// </summary>
        /// <param name="since">Loads events updated afer this date</param>
        public void Load(DateTime since)
        {
            scopes.Add(CalendarService.Scope.Calendar);

            UserCredential credential;
            using (FileStream stream = new FileStream("client_secret.json", FileMode.Open, FileAccess.Read))
            {
                try
                {
                    credential = GoogleWebAuthorizationBroker.AuthorizeAsync(GoogleClientSecrets.Load(stream).Secrets, scopes, "user", CancellationToken.None, new FileDataStore("UpdateSync")).Result;
                }
                catch (Exception e)
                {
                    Console.WriteLine(e.Message);
                    credential = null;
                }
            }

            BaseClientService.Initializer initializer = new BaseClientService.Initializer();
            initializer.HttpClientInitializer = credential;
            initializer.ApplicationName = "UpdateSync";
            service = new CalendarService(initializer);

            IList<CalendarListEntry> calendars = service.CalendarList.List().Execute().Items;

            foreach (CalendarListEntry item in calendars)
            {
                Console.WriteLine(item.Summary + ". Location: " + item.Location + ", TimeZone: " + item.TimeZone);
            }
        }
    }
}

/*
Private Sub DisplayList(list As IList(Of CalendarListEntry))
    Console.WriteLine("Lists of calendars:")
    For Each item As CalendarListEntry In list
        Console.WriteLine(item.Summary & ". Location: " & item.Location & ", TimeZone: " & item.TimeZone)
    Next
End Sub

''' <summary>Displays the calendar's events.</summary>
Private Sub DisplayFirstCalendarEvents(list As CalendarListEntry)
    Console.WriteLine(Environment.NewLine & "Maximum 5 first events from {0}:", list.Summary)
    Dim requeust As ListRequest = service.Events.List(list.Id)
    ' Set MaxResults and TimeMin with sample values
    requeust.MaxResults = 5
    requeust.TimeMin = "2012-01-01T00:00:00-00:00"
    ' Fetch the list of events
    For Each calendarEvent As Data.Event In requeust.Execute().Items
        Dim startDate As String = "Unspecified"
        If (Not calendarEvent.Start Is Nothing) Then
            If (Not calendarEvent.Start.Date Is Nothing) Then
                startDate = calendarEvent.Start.Date.ToString()
            End If
        End If

        Console.WriteLine(calendarEvent.Summary & ". Start at: " & startDate)
    Next
End Sub
*/
